@@ -1,7 +1,6 @@
 from adam.commands.command import Command
 from adam.commands.cql.cql_utils import tables as get_tables, run_cql
 from adam.config import Config
-from adam.pod_exec_result import PodExecResult
 from adam.repl_state import ReplState, RequiredState
 from adam.utils import log2
 
@@ -44,11 +43,6 @@ class AlterTables(Command):
         args, include_reaper = Command.extract_options(args, '--include-reaper')
         arg_str = ' '.join(args)
 
-        # r: list[PodExecResult] = run_cql(state, 'describe tables', show_out=False, on_any=True)
-        # if not r:
-        #     log2('No pod is available')
-        #     return 'no-pod'
-
         excludes = [e.strip(' \r\n') for e in Config().get(
             'cql.alter-tables.excludes',
             'system_auth,system_traces,reaper_db,system_distributed,system_views,system,system_schema,system_virtual_schema').split(',')]
@@ -79,14 +73,9 @@ class AlterTables(Command):
         # do not continue to cql route
         return state
 
-    def completion(self, state: ReplState) -> dict[str, any]:
-        if state.sts:
-            ps = Config().get('cql.alter-tables.gc-grace-periods', '3600,86400,864000,7776000').split(',')
-            return super().completion(state, {
-                'GC_GRACE_SECONDS': {'=': {p.strip(' \r\n'): {'--include-reaper': None} for p in ps}},
-            })
-
+    def completion(self, _: ReplState) -> dict[str, any]:
+        # auto completion is taken care of by sql completer
         return {}
 
     def help(self, _: ReplState) -> str:
-        return f'{AlterTables.COMMAND} <param = value> [--include-reaper] \t alter on all tables'
\ No newline at end of file
+        return f'{AlterTables.COMMAND} <param = value> [--include-reaper] \t alter schema on all tables'
\ No newline at end of file
