@@ -1,6 +1,6 @@
 from adam.commands.command import Command
 from adam.commands.postgres.postgres_utils import pg_database_names
-from adam.commands.postgres.postgres_session import PostgresSession
+from adam.commands.postgres.postgres_context import PostgresContext
 from adam.utils_k8s.cassandra_clusters import CassandraClusters
 from adam.utils_k8s.kube_context import KubeContext
 from adam.utils_k8s.statefulsets import StatefulSets
@@ -23,10 +23,16 @@ class Cd(Command):
     def command(self):
         return Cd.COMMAND
 
+    def required(self):
+        return ReplState.NON_L
+
     def run(self, cmd: str, state: ReplState):
         if not(args := self.args(cmd)):
             return super().run(cmd, state)
 
+        if not self.validate_state(state):
+            return state
+
         if len(args) < 2:
             return state
 
@@ -36,11 +42,11 @@ class Cd(Command):
                 if dir == '':
                     state.pg_path = None
                 else:
-                    session = PostgresSession(state.namespace, state.pg_path)
+                    context: PostgresContext = PostgresContext.apply(state.namespace, state.pg_path, arg=dir)
                     # patch up state.namespace from pg cd
-                    if not state.namespace and (ns := session.find_namespace(arg)):
-                        state.namespace = ns
-                    state.pg_path = session.directory(arg)
+                    if not state.namespace and context.namespace:
+                        state.namespace = context.namespace
+                    state.pg_path = context.path()
             elif state.device == ReplState.A:
                 if dir == '':
                     state.app_env = None
@@ -91,13 +97,13 @@ class Cd(Command):
 
     def completion(self, state: ReplState):
         if state.device == ReplState.P:
-            pg = PostgresSession(state.namespace, state.pg_path) if state.pg_path else None
+            pg: PostgresContext = PostgresContext.apply(state.namespace, state.pg_path) if state.pg_path else None
             if pg and pg.db:
                 return {Cd.COMMAND: {'..': None}}
             elif pg and pg.host:
-                return {Cd.COMMAND: {'..': None} | {p: None for p in pg_database_names(state.namespace, pg.directory())}}
+                return {Cd.COMMAND: {'..': None} | {p: None for p in pg_database_names(state.namespace, pg.path())}}
             else:
-                return {Cd.COMMAND: {p: None for p in PostgresSession.hosts(state.namespace)}}
+                return {Cd.COMMAND: {p: None for p in PostgresContext.hosts(state.namespace)}}
         elif state.device == ReplState.A:
             if state.app_app:
                 return {Cd.COMMAND: {'..': None}}
