@@ -23,19 +23,19 @@ def keyspaces(state: ReplState, on_any=False):
 
     return parse_cql_desc_keyspaces(r.stdout if state.pod else r[0].stdout)
 
-def table_names(state: ReplState):
+def cassandra_table_names(state: ReplState):
     return [f'{k}.{t}' for k, ts in tables(state, on_any=True).items() for t in ts]
 
 @functools.lru_cache()
-def tables(state: ReplState, on_any=False):
+def tables(state: ReplState, on_any=False) -> dict[str, list[str]]:
     r: list[PodExecResult] = run_cql(state, 'describe tables', show_out=False, on_any=on_any)
     if not r:
         log2('No pod is available')
-        return []
+        return {}
 
     return parse_cql_desc_tables(r.stdout if state.pod else r[0].stdout)
 
-def run_cql(state: ReplState, cql: str, opts: list = [], show_out = False, use_single_quotes = False, on_any = False):
+def run_cql(state: ReplState, cql: str, opts: list = [], show_out = False, use_single_quotes = False, on_any = False, background=False) -> list[PodExecResult]:
     user, pw = Secrets.get_user_pass(state.sts if state.sts else state.pod, state.namespace, secret_path='cql.secret')
     if use_single_quotes:
         command = f"cqlsh -u {user} -p {pw} {' '.join(opts)} -e '{cql}'"
@@ -43,9 +43,9 @@ def run_cql(state: ReplState, cql: str, opts: list = [], show_out = False, use_s
         command = f'cqlsh -u {user} -p {pw} {" ".join(opts)} -e "{cql}"'
 
     if state.pod:
-        return CassandraNodes.exec(state.pod, state.namespace, command, show_out=show_out)
+        return CassandraNodes.exec(state.pod, state.namespace, command, show_out=show_out, background=background)
     else:
-        return CassandraClusters.exec(state.sts, state.namespace, command, show_out=show_out, action='cql', on_any=on_any)
+        return CassandraClusters.exec(state.sts, state.namespace, command, show_out=show_out, action='cql', on_any=on_any, background=background)
 
 def parse_cql_desc_tables(out: str):
     # Keyspace data_endpoint_auth
