@@ -5,12 +5,12 @@ from adam.commands.command import Command
 from adam.commands.deploy.deploy_utils import creating, deploy_frontend, gen_labels
 from adam.commands.deploy.undeploy_pod import UndeployPod
 from adam.config import Config
-from adam.k8s_utils.config_maps import ConfigMaps
-from adam.k8s_utils.deployment import Deployments
-from adam.k8s_utils.kube_context import KubeContext
-from adam.k8s_utils.pods import Pods
-from adam.k8s_utils.service_accounts import ServiceAccounts
-from adam.k8s_utils.volumes import ConfigMapMount
+from adam.utils_k8s.config_maps import ConfigMaps
+from adam.utils_k8s.deployment import Deployments
+from adam.utils_k8s.kube_context import KubeContext
+from adam.utils_k8s.pods import Pods
+from adam.utils_k8s.service_accounts import ServiceAccounts
+from adam.utils_k8s.volumes import ConfigMapMount
 from adam.repl_state import ReplState, RequiredState
 from adam.utils import log2
 
