@@ -7,4 +7,4 @@ def psql_completions(ns: str, pg_path: str):
         '\d': None,
         '\dt': None,
         '\du': None
-    } | SqlCompleter.completions(lambda: pg_table_names(ns, pg_path))
\ No newline at end of file
+    } | SqlCompleter(lambda: pg_table_names(ns, pg_path)).completions_for_nesting()
\ No newline at end of file
