@@ -1,5 +1,5 @@
 from adam.commands.command import Command
-from adam.k8s_utils.pods import Pods
+from adam.utils_k8s.pods import Pods
 from .reaper_session import ReaperSession
 from adam.repl_state import ReplState, RequiredState
 
