@@ -28,6 +28,8 @@ class Repair(Command):
     def run(self, cmd: str, state: ReplState):
         if not(args := self.args(cmd)):
             return super().run(cmd, state)
+        if not self.validate_state(state):
+            return state
 
         return super().intermediate_run(cmd, state, args, Repair.cmd_list())
 
@@ -35,9 +37,7 @@ class Repair(Command):
         return [RepairRun(), RepairScan(), RepairStop(), RepairLog()]
 
     def completion(self, state: ReplState):
-        if state.sts:
-            return super().completion(state)
-        return {}
+        return super().completion(state)
 
 class RepairCommandHelper(click.Command):
     def get_help(self, ctx: click.Context):
