@@ -1,5 +1,5 @@
 from adam.commands.command import Command
-from adam.k8s_utils.custom_resources import CustomResources
+from adam.utils_k8s.custom_resources import CustomResources
 from adam.repl_state import ReplState, RequiredState
 from adam.utils import log
 
