@@ -18,14 +18,15 @@ class ShowAppQueues(Command):
         return ShowAppQueues.COMMAND
 
     def required(self):
-        return RequiredState.CLUSTER_OR_POD
+        return RequiredState.APP_APP
 
     def run(self, cmd: str, state: ReplState):
         if not(args := self.args(cmd)):
             return super().run(cmd, state)
 
         state, args = self.apply_state(args, state)
-        if not self.validate_state(state, app_required=RequiredState.APP_APP):
+        # if not self.validate_state(state, app_required=RequiredState.APP_APP):
+        if not self.validate_state(state):
             return state
 
         _, forced = Command.extract_options(args, '--force')
