@@ -39,7 +39,7 @@ class Config:
         return get_deep_keys(self.params)
 
     def is_debug(self):
-        return os.getenv('QING_DEV').lower() == 'true' or Config().get('debug', False)
+        return os.getenv('QING_DEV', 'false').lower() == 'true' or Config().get('debug', False)
 
     def debug(self, s: None):
         if self.is_debug():
