@@ -32,4 +32,7 @@ class PodExecResult:
         except:
             pass
 
-        return code
\ No newline at end of file
+        return code
+
+    def __audit_extra__(self):
+        return self.log_file if self.log_file else None
\ No newline at end of file
