@@ -1,4 +1,3 @@
-import getpass
 import os
 import re
 import time
@@ -7,14 +6,14 @@ import click
 import concurrent
 from prompt_toolkit.completion import NestedCompleter
 from prompt_toolkit.key_binding import KeyBindings
-import requests
 
 from adam.cli_group import cli
 from adam.commands.command import Command
 from adam.commands.command_helpers import ClusterCommandHelper
 from adam.commands.help import Help
-from adam.commands.postgres.postgres_session import PostgresSession
+from adam.commands.postgres.postgres_context import PostgresContext
 from adam.config import Config
+from adam.utils_audits import Audits
 from adam.utils_k8s.kube_context import KubeContext
 from adam.utils_k8s.statefulsets import StatefulSets
 from adam.log import Log
@@ -23,7 +22,6 @@ from adam.repl_session import ReplSession
 from adam.repl_state import ReplState
 from adam.utils import deep_merge_dicts, deep_sort_dict, lines_to_tabular, log2
 from adam.apps import Apps
-from adam.utils_net import get_my_host
 from . import __version__
 
 def enter_repl(state: ReplState):
@@ -40,7 +38,7 @@ def enter_repl(state: ReplState):
         msg = ''
         if state.device == ReplState.P:
             msg = f'{ReplState.P}:'
-            pg = PostgresSession(state.namespace, state.pg_path) if state.pg_path else None
+            pg: PostgresContext = PostgresContext.apply(state.namespace, state.pg_path) if state.pg_path else None
             if pg and pg.db:
                 msg += pg.db
             elif pg and pg.host:
@@ -69,23 +67,24 @@ def enter_repl(state: ReplState):
     Log.log2(f'kaqing {__version__}')
 
     if state.device == ReplState.C:
-        auto_enter = Config().get('repl.auto-enter-only-cluster', 'cluster')
-        ss = StatefulSets.list_sts_name_and_ns()
-        if not ss:
-            raise Exception("no Cassandra clusters found")
-        elif not state.sts and len(ss) == 1 and auto_enter in ['cluster', 'first-pod']:
-            cluster = ss[0]
-            state.sts = cluster[0]
-            state.namespace = cluster[1]
-            if auto_enter == 'first-pod':
-                state.pod = f'{state.sts}-0'
-            if KubeContext().in_cluster_namespace:
-                Config().wait_log(f'Moving to the only Cassandra cluster: {state.sts}...')
-            else:
-                Config().wait_log(f'Moving to the only Cassandra cluster: {state.sts}@{state.namespace}...')
+        auto_enter = Config().get('repl.c.auto-enter', 'cluster')
+        if auto_enter and auto_enter in ['cluster', 'first-pod']:
+            ss = StatefulSets.list_sts_name_and_ns()
+            if not ss:
+                log2("No Cassandra clusters found.")
+            elif not state.sts and len(ss) == 1:
+                cluster = ss[0]
+                state.sts = cluster[0]
+                state.namespace = cluster[1]
+                if auto_enter == 'first-pod':
+                    state.pod = f'{state.sts}-0'
+                if KubeContext().in_cluster_namespace:
+                    Config().wait_log(f'Moving to the only Cassandra cluster: {state.sts}...')
+                else:
+                    Config().wait_log(f'Moving to the only Cassandra cluster: {state.sts}@{state.namespace}...')
     elif state.device == ReplState.A:
         if not state.app_env:
-            if app := Config().get('repl.auto-enter-app', 'c3/c3'):
+            if app := Config().get('repl.a.auto-enter-app', 'c3/c3'):
                 if app != 'no':
                     ea = app.split('/')
                     state.app_env = ea[0]
@@ -105,11 +104,14 @@ def enter_repl(state: ReplState):
 
     with concurrent.futures.ThreadPoolExecutor(max_workers=Config().get('audit.workers', 3)) as executor:
         # warm up AWS lambda - this log line may timeout and get lost, which is fine
-        executor.submit(audit_log, 'entering kaqing repl', state)
+        executor.submit(Audits.log, 'entering kaqing repl', state.namespace, 'z', 0.0)
+
+        s0 = time.time()
 
         # use sorted command list only for auto-completion
         sorted_cmds = sorted(cmd_list, key=lambda cmd: cmd.command())
         while True:
+            result = None
             try:
                 completer = NestedCompleter.from_nested_dict({})
                 if not state.bash_session:
@@ -139,33 +141,9 @@ def enter_repl(state: ReplState):
 
                     cmd = f'bash {cmd}'
 
-                if cmd and cmd.strip(' ') and not cmds.run(cmd, state):
-                    c_sql_tried = False
-                    if state.device == ReplState.P:
-                        pg = PostgresSession(state.namespace, state.pg_path)
-                        if pg.db:
-                            c_sql_tried = True
-                            cmd = f'pg {cmd}'
-                            cmds.run(cmd, state)
-                    elif state.device == ReplState.A:
-                        if state.app_app:
-                            c_sql_tried = True
-                            cmd = f'app {cmd}'
-                            cmds.run(cmd, state)
-                    elif state.device == ReplState.L:
-                        c_sql_tried = True
-                        cmd = f'audit {cmd}'
-                        cmds.run(cmd, state)
-                    elif state.sts:
-                        c_sql_tried = True
-                        cmd = f'cql {cmd}'
-                        cmds.run(cmd, state)
-
-                    if not c_sql_tried:
-                        log2(f'* Invalid command: {cmd}')
-                        log2()
-                        lines = [c.help(state) for c in cmd_list if c.help(state)]
-                        log2(lines_to_tabular(lines, separator='\t'))
+                if cmd and cmd.strip(' ') and not (result := cmds.run(cmd, state)):
+                    # not served by any command in the chain; try SQL query or C3 action
+                    result = try_device_default_action(state, cmds, cmd_list, cmd)
             except EOFError:  # Handle Ctrl+D (EOF) for graceful exit
                 break
             except Exception as e:
@@ -181,25 +159,55 @@ def enter_repl(state: ReplState):
 
                 # offload audit logging
                 if cmd and (state.device != ReplState.L or Config().get('audit.log-audit-queries', False)):
-                    executor.submit(audit_log, cmd, state)
+                    executor.submit(Audits.log, cmd, state.namespace, state.device, time.time() - s0, get_audit_extra(result))
 
-def audit_log(cmd: str, state: ReplState):
-    payload = {
-        'cluster': state.namespace if state.namespace else 'NA',
-        'ts': time.time(),
-        'host': get_my_host(),
-        'user': getpass.getuser(),
-        'line': cmd.replace('"', '""').replace('\n', ' '),
-    }
-    audit_endpoint = Config().get("audit.endpoint", "https://4psvtaxlcb.execute-api.us-west-2.amazonaws.com/prod/")
-    try:
-        response = requests.post(audit_endpoint, json=payload, timeout=Config().get("audit.timeout", 10))
-        if response.status_code in [200, 201]:
-            Config().debug(response.text)
-        else:
-            log2(f"Error: {response.status_code} {response.text}")
-    except requests.exceptions.Timeout as e:
-        log2(f"Timeout occurred: {e}")
+def try_device_default_action(state: ReplState, cmds: Command, cmd_list: list[Command], cmd: str):
+    result = None
+
+    c_sql_tried = False
+    if state.device == ReplState.P:
+        pg: PostgresContext = PostgresContext.apply(state.namespace, state.pg_path)
+        if pg.db:
+            c_sql_tried = True
+            cmd = f'pg {cmd}'
+            result = cmds.run(cmd, state)
+    elif state.device == ReplState.A:
+        if state.app_app:
+            c_sql_tried = True
+            cmd = f'app {cmd}'
+            result = cmds.run(cmd, state)
+    elif state.device == ReplState.L:
+        c_sql_tried = True
+        cmd = f'audit {cmd}'
+        result = cmds.run(cmd, state)
+    elif state.sts:
+        c_sql_tried = True
+        cmd = f'cql {cmd}'
+        result = cmds.run(cmd, state)
+
+    if not c_sql_tried:
+        log2(f'* Invalid command: {cmd}')
+        log2()
+        lines = [c.help(state) for c in cmd_list if c.help(state)]
+        log2(lines_to_tabular(lines, separator='\t'))
+
+    return result
+
+def get_audit_extra(result: any):
+    if not result:
+        return None
+
+    if type(result) is list:
+        extras = set()
+
+        for r in result:
+            if hasattr(r, '__audit_extra__') and (x := r.__audit_extra__()):
+                extras.add(x)
+
+        return ','.join(list(extras))
+
+    if hasattr(result, '__audit_extra__') and (x := result.__audit_extra__()):
+        return x
 
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterCommandHelper, help="Enter interactive shell.")
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
