@@ -1,8 +1,10 @@
 import copy
 from enum import Enum
 import re
+import traceback
+from typing import Callable
 
-from adam.commands.postgres.postgres_session import PostgresSession
+from adam.commands.postgres.postgres_context import PostgresContext
 from adam.utils_k8s.cassandra_clusters import CassandraClusters
 from adam.utils_k8s.cassandra_nodes import CassandraNodes
 from adam.utils_k8s.kube_context import KubeContext
@@ -51,6 +53,9 @@ class ReplState:
     L = 'l'
     P = 'p'
 
+    ANY = [A, C, L, P]
+    NON_L = [A, C, P]
+
     def __init__(self, device: str = None,
                  sts: str = None, pod: str = None, namespace: str = None, ns_sts: str = None,
                  pg_path: str = None,
@@ -166,72 +171,169 @@ class ReplState:
 
         return (state, new_args)
 
-    def validate(self, required: RequiredState = None, pg_required: RequiredState = None, app_required: RequiredState = None):
-        if not pg_required and not app_required:
-            if required == RequiredState.CLUSTER:
-                if not self.namespace or not self.sts:
+    def validate(self, required: list[RequiredState] = [], show_err = True):
+        if not required:
+            return True
+
+        def default_err():
+            if self.in_repl:
+                log2(f'Not a valid command on {self.device}: drive.')
+            else:
+                log2('* on a wrong device.')
+                log2()
+                display_help()
+
+        if type(required) is not list:
+            valid, err = self._validate(required)
+            if valid:
+                return True
+
+            if show_err:
+                if err:
+                    err()
+                else:
+                    default_err()
+
+            return False
+
+        devices = [r for r in required if r in [ReplState.L, ReplState.A, ReplState.C, ReplState.P]]
+        non_devices = [r for r in required if r not in [ReplState.L, ReplState.A, ReplState.C, ReplState.P]]
+
+        first_error: Callable = None
+        for r in non_devices:
+            valid, err = self._validate(r)
+            if valid:
+                return True
+
+            if not first_error:
+                first_error = err
+
+        if devices:
+            valid, err = self._validate_device(devices)
+            if valid:
+                return True
+
+            if not first_error:
+                first_error = err
+
+        if show_err and first_error:
+            if first_error:
+                first_error()
+            else:
+                default_err()
+
+        return False
+
+    def _validate(self, required: RequiredState):
+        if required == RequiredState.CLUSTER:
+            if self.device != ReplState.C:
+                return (False, None)
+
+            if not self.namespace or not self.sts:
+                def error():
                     if self.in_repl:
                         log2('cd to a Cassandra cluster first.')
                     else:
                         log2('* Cassandra cluster is missing.')
                         log2()
                         display_help()
+                return (False, error)
 
-                    return False
-            elif required == RequiredState.POD:
-                if not self.namespace or not self.pod:
+        elif required == RequiredState.POD:
+            if self.device != ReplState.C:
+                return (False, None)
+
+            if not self.namespace or not self.pod:
+                def error():
                     if self.in_repl:
                         log2('cd to a pod first.')
                     else:
                         log2('* Pod is missing.')
                         log2()
                         display_help()
+                return (False, error)
 
-                    return False
-            elif required == RequiredState.CLUSTER_OR_POD:
-                if not self.namespace or not self.sts and not self.pod:
+        elif required == RequiredState.CLUSTER_OR_POD:
+            if self.device != ReplState.C:
+                return (False, None)
+
+            if not self.namespace or not self.sts and not self.pod:
+                def error():
                     if self.in_repl:
                         log2('cd to a Cassandra cluster first.')
                     else:
                         log2('* Cassandra cluster or pod is missing.')
                         log2()
                         display_help()
+                return (False, error)
 
-                    return False
-            elif required == RequiredState.NAMESPACE:
-                if not self.namespace:
+        elif required == RequiredState.NAMESPACE:
+            if self.device != ReplState.C:
+                return (False, None)
+
+            if not self.namespace:
+                def error():
                     if self.in_repl:
                         log2('Namespace is required.')
                     else:
                         log2('* namespace is missing.')
                         log2()
                         display_help()
+                return (False, error)
 
-                    return False
+        elif required == RequiredState.PG_DATABASE:
+            if self.device != ReplState.P:
+                return (False, None)
 
-        if pg_required == RequiredState.PG_DATABASE:
-            pg = PostgresSession(self.namespace, self.pg_path)
+            pg: PostgresContext = PostgresContext.apply(self.namespace, self.pg_path)
             if not pg.db:
+                def error():
+                    if self.in_repl:
+                        log2('cd to a database first.')
+                    else:
+                        log2('* database is missing.')
+                        log2()
+                        display_help()
+                return (False, error)
+
+        elif required == RequiredState.APP_APP:
+            if self.device != ReplState.A:
+                return (False, None)
+
+            if not self.app_app:
+                def error():
+                    if self.in_repl:
+                        log2('cd to an app first.')
+                    else:
+                        log2('* app is missing.')
+                        log2()
+                        display_help()
+                return (False, error)
+
+        elif required in [ReplState.L, ReplState.A, ReplState.C, ReplState.P] and self.device != required:
+            def error():
                 if self.in_repl:
-                    log2('cd to a database first.')
+                    log2(f'Switch to {required}: first.')
                 else:
-                    log2('* database is missing.')
+                    log2('* on a wrong device.')
                     log2()
                     display_help()
+            return (False, error)
 
-                return False
+        return (True, None)
 
-        if app_required == RequiredState.APP_APP and not self.app_app:
-            if self.in_repl:
-                log2('cd to an app first.')
-            else:
-                log2('* app is missing.')
-                log2()
-                display_help()
+    def _validate_device(self, devices: list[RequiredState]):
+        if self.device not in devices:
+            def error():
+                if self.in_repl:
+                    log2(f'Not a valid command on {self.device}: drive.')
+                else:
+                    log2('* on a wrong device.')
+                    log2()
+                    display_help()
+            return (False, error)
 
-            return False
-
-        return True
+        return (True, None)
 
     def user_pass(self, secret_path = 'cql.secret'):
         return Secrets.get_user_pass(self.pod if self.pod else self.sts, self.namespace, secret_path=secret_path)
