@@ -9,7 +9,7 @@ import requests
 from kubernetes import config
 import yaml
 
-from adam.k8s_utils.secrets import Secrets
+from adam.utils_k8s.secrets import Secrets
 
 from .cred_cache import CredCache
 from .idp_session import IdpSession
