@@ -6,11 +6,11 @@ from adam.repl_session import ReplSession
 
 # utility collection on cassandra nodes; methods are all static
 class CassandraNodes:
-    def exec(pod_name: str, namespace: str, command: str, show_out = True, throw_err = False, shell = '/bin/sh') -> PodExecResult:
-        r = Pods.exec(pod_name, "cassandra", namespace, command, show_out = show_out, throw_err = throw_err, shell = shell)
+    def exec(pod_name: str, namespace: str, command: str, show_out = True, throw_err = False, shell = '/bin/sh', background = False) -> PodExecResult:
+        r = Pods.exec(pod_name, "cassandra", namespace, command, show_out = show_out, throw_err = throw_err, shell = shell, background = background)
 
         if r and Config().get('repl.history.push-cat-remote-log-file', True):
-            if r.log_file:
+            if r.log_file and ReplSession().prompt_session:
                 ReplSession().prompt_session.history.append_string(f'bash {r.pod} cat {r.log_file}')
 
         return r
